pub struct RedisConnectionInfo {
pub db: i64,
pub username: Option<String>,
pub password: Option<String>,
pub protocol: ProtocolVersion,
}Expand description
This is a 1:1 copy of the redis::RedisConnectionInfo struct.
This is duplicated here in order to add support for the
serde::Deserialize trait which is required for the serde support.
Fields
db: i64The database number to use. This is usually 0.
username: Option<String>Optionally a username that should be used for connection.
password: Option<String>Optionally a password that should be used for connection.
protocol: ProtocolVersionVersion of the protocol to use.